@@ -31,26 +31,35 @@ PuLP: An LP modeler in Python
 PuLP is an LP modeler written in python. PuLP can generate MPS or LP files
 and call GLPK, COIN CLP/CBC, CPLEX and XPRESS to solve linear problems.
 
-A comprehensive wiki can be found at http://130.216.209.237/engsci392/pulp/OptimisationWithPuLP
+A comprehensive wiki can be found at http://pulp-or.googlecode.com/
 
-Use LpVariable() to create new variables. ex:
-x = LpVariable("x", 0, 3)
-to create a variable 0 <= x <= 3
+Use LpVariable() to create new variables. To create a variable 0 <= x <= 3
+>>> x = LpVariable("x", 0, 3)
 
-Use LpProblem() to create new problems. ex:
-prob = LpProblem("myProblem", LpMinimize)
+To create a variable 0 <= y <= 1
+>>> y = LpVariable("y", 0, 1)
+
+Use LpProblem() to create new problems. Create "myProblem"
+>>> prob = LpProblem("myProblem", LpMinimize)
 
 Combine variables to create expressions and constraints and add them to the
-problem. ex:
-prob += x + y <= 2
-If you add an expression (not a constraint, f.e. prob += 4*z + w), it will
+problem. 
+>>> prob += x + y <= 2
+
+If you add an expression (not a constraint), it will
 become the objective.
+>>> prob += -4*x + y
 
 Choose a solver and solve the problem. ex:
-prob.solve(GLPK())
+>>> status = prob.solve(GLPK(msg = 0))
+
+Display the status of the solution
+>>> LpStatus[status]
+'Optimal'
 
 You can get the value of the variables using value(). ex:
-value(x)
+>>> value(x)
+2.0
 
 Exported Classes:
     - LpProblem -- Container class for a Linear programming problem
